## Operator Schemas

This file lists the QONNX custom operators, similar to `Operators.md` for the ONNX standard.
It is manually updated, since QONNX custom operators are relatively few in number.

### qonnx.custom_op.general

|**Operator**|**Since version**||
|-|-|-|
|[BipolarQuant](bipolarquant_v1.md) | [1](bipolarquant_v1.md)||
|[FloatQuant](floatquant_v1.md)      | [1](floatquant_v1.md)||
|[IntQuant](intquant_v1.md)          | [1](intquant_v1.md)||
|[Trunc](trunc_v2.md)                | [2](trunc_v2.md), [1](trunc_v1.md)||
